==> cabal-fmt-0.1.6-74-x86_64.pkg.tar.zst: usr/share/haskell/register/cabal-fmt.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 z-cabal-fmt-z-version-interval
version:              0.1.6
package-name:         cabal-fmt
lib-name:             version-interval
id:                   cabal-fmt-0.1.6-78hFPekNVsIE8XOsKyq9aZ-version-interval
key:                  cabal-fmt-0.1.6-78hFPekNVsIE8XOsKyq9aZ-version-interval
license:              GPL-3.0-or-later AND BSD-3-Clause
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
synopsis:             Format .cabal files
description:
    Format @.cabal@ files preserving the original field ordering, and comments.

    Tuned for Oleg'\''s preference, but has some knobs still.

category:             Development
abi:                  98a8ecfec95355de22ed2302ebc279a9
exposed-modules:      VersionInterval
import-dirs:          /usr/lib/ghc-9.4.8/site-local/cabal-fmt-0.1.6
library-dirs:         /usr/lib/ghc-9.4.8/site-local/cabal-fmt-0.1.6
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/cabal-fmt-0.1.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/cabal-fmt
hs-libraries:         HScabal-fmt-0.1.6-78hFPekNVsIE8XOsKyq9aZ-version-interval
depends:              Cabal-syntax-3.8.1.0 base-4.17.2.1
haddock-interfaces:   /usr/share/doc/cabal-fmt/html/cabal-fmt.haddock
haddock-html:         /usr/share/doc/cabal-fmt/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 z-cabal-fmt-z-cabal-fmt-internal
version:              0.1.6
package-name:         cabal-fmt
lib-name:             cabal-fmt-internal
id:                   cabal-fmt-0.1.6-HaZBMnJM89uFF9W8VURn7-cabal-fmt-internal
key:                  cabal-fmt-0.1.6-HaZBMnJM89uFF9W8VURn7-cabal-fmt-internal
license:              GPL-3.0-or-later AND BSD-3-Clause
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
synopsis:             Format .cabal files
description:
    Format @.cabal@ files preserving the original field ordering, and comments.

    Tuned for Oleg'\''s preference, but has some knobs still.

category:             Development
abi:                  e884760183caeb2a9500850b6ec8a19f
exposed-modules:
    CabalFmt CabalFmt.Comments CabalFmt.Error CabalFmt.Fields
    CabalFmt.Fields.BuildDepends CabalFmt.Fields.Extensions
    CabalFmt.Fields.Modules CabalFmt.Fields.SourceFiles
    CabalFmt.Fields.TestedWith CabalFmt.Glob CabalFmt.Monad
    CabalFmt.Options CabalFmt.Parser CabalFmt.Pragma CabalFmt.Prelude
    CabalFmt.Refactoring CabalFmt.Refactoring.ExpandExposedModules
    CabalFmt.Refactoring.Fragments CabalFmt.Refactoring.GlobFiles
    CabalFmt.Refactoring.Type

import-dirs:          /usr/lib/ghc-9.4.8/site-local/cabal-fmt-0.1.6
library-dirs:         /usr/lib/ghc-9.4.8/site-local/cabal-fmt-0.1.6
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/cabal-fmt-0.1.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/cabal-fmt
hs-libraries:         HScabal-fmt-0.1.6-HaZBMnJM89uFF9W8VURn7-cabal-fmt-internal
depends:
    Cabal-syntax-3.8.1.0 base-4.17.2.1 bytestring-0.11.5.3
    cabal-fmt-0.1.6-78hFPekNVsIE8XOsKyq9aZ-version-interval
    containers-0.6.7 directory-1.3.7.1 filepath-1.4.2.2 mtl-2.2.2
    parsec-3.1.16.1 pretty-1.1.3.6

haddock-interfaces:   /usr/share/doc/cabal-fmt/html/cabal-fmt.haddock
haddock-html:         /usr/share/doc/cabal-fmt/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> cabal-fmt-0.1.6-75-x86_64.pkg.tar.zst: usr/share/haskell/register/cabal-fmt.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 z-cabal-fmt-z-version-interval
version:              0.1.6
package-name:         cabal-fmt
lib-name:             version-interval
id:                   cabal-fmt-0.1.6-HrNtddz4F6eHVZsXUMRYd7-version-interval
key:                  cabal-fmt-0.1.6-HrNtddz4F6eHVZsXUMRYd7-version-interval
license:              GPL-3.0-or-later AND BSD-3-Clause
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
synopsis:             Format .cabal files
description:
    Format @.cabal@ files preserving the original field ordering, and comments.

    Tuned for Oleg'\''s preference, but has some knobs still.

category:             Development
abi:                  c6521569adcdbda3cc0d26bb8bb64618
exposed-modules:      VersionInterval
import-dirs:          /usr/lib/ghc-9.4.8/site-local/cabal-fmt-0.1.6
library-dirs:         /usr/lib/ghc-9.4.8/site-local/cabal-fmt-0.1.6
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/cabal-fmt-0.1.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/cabal-fmt
hs-libraries:         HScabal-fmt-0.1.6-HrNtddz4F6eHVZsXUMRYd7-version-interval
depends:              Cabal-syntax-3.8.1.0 base-4.17.2.1
haddock-interfaces:   /usr/share/doc/cabal-fmt/html/cabal-fmt.haddock
haddock-html:         /usr/share/doc/cabal-fmt/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 z-cabal-fmt-z-cabal-fmt-internal
version:              0.1.6
package-name:         cabal-fmt
lib-name:             cabal-fmt-internal
id:                   cabal-fmt-0.1.6-6o2QWX7wsJmB54FV4BVi21-cabal-fmt-internal
key:                  cabal-fmt-0.1.6-6o2QWX7wsJmB54FV4BVi21-cabal-fmt-internal
license:              GPL-3.0-or-later AND BSD-3-Clause
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
synopsis:             Format .cabal files
description:
    Format @.cabal@ files preserving the original field ordering, and comments.

    Tuned for Oleg'\''s preference, but has some knobs still.

category:             Development
abi:                  0cf50e597d3da8521225c4f743c7b53b
exposed-modules:
    CabalFmt CabalFmt.Comments CabalFmt.Error CabalFmt.Fields
    CabalFmt.Fields.BuildDepends CabalFmt.Fields.Extensions
    CabalFmt.Fields.Modules CabalFmt.Fields.SourceFiles
    CabalFmt.Fields.TestedWith CabalFmt.Glob CabalFmt.Monad
    CabalFmt.Options CabalFmt.Parser CabalFmt.Pragma CabalFmt.Prelude
    CabalFmt.Refactoring CabalFmt.Refactoring.ExpandExposedModules
    CabalFmt.Refactoring.Fragments CabalFmt.Refactoring.GlobFiles
    CabalFmt.Refactoring.Type

import-dirs:          /usr/lib/ghc-9.4.8/site-local/cabal-fmt-0.1.6
library-dirs:         /usr/lib/ghc-9.4.8/site-local/cabal-fmt-0.1.6
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/cabal-fmt-0.1.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/cabal-fmt
hs-libraries:         HScabal-fmt-0.1.6-6o2QWX7wsJmB54FV4BVi21-cabal-fmt-internal
depends:
    Cabal-syntax-3.8.1.0 base-4.17.2.1 bytestring-0.11.5.3
    cabal-fmt-0.1.6-HrNtddz4F6eHVZsXUMRYd7-version-interval
    containers-0.6.7 directory-1.3.7.1 filepath-1.4.2.2 mtl-2.2.2
    parsec-3.1.16.1 pretty-1.1.3.6

haddock-interfaces:   /usr/share/doc/cabal-fmt/html/cabal-fmt.haddock
haddock-html:         /usr/share/doc/cabal-fmt/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
